@@ -17,11 +17,11 @@ from syned.beamline.beamline_element import BeamlineElement
 from syned.beamline.shape import *
 
 from wofry.propagator.propagator import PropagationManager, PropagationElements, PropagationParameters
-from wofry.propagator.propagators2D.fresnel import Fresnel2D
-from wofry.propagator.propagators2D.fresnel_convolution import FresnelConvolution2D
-from wofry.propagator.propagators2D.fraunhofer import Fraunhofer2D
-from wofry.propagator.propagators2D.integral import Integral2D
-from wofry.propagator.propagators2D.fresnel_zoom_xy import FresnelZoomXY2D
+from wofryimpl.propagator.propagators2D.fresnel import Fresnel2D
+from wofryimpl.propagator.propagators2D.fresnel_convolution import FresnelConvolution2D
+from wofryimpl.propagator.propagators2D.fraunhofer import Fraunhofer2D
+from wofryimpl.propagator.propagators2D.integral import Integral2D
+from wofryimpl.propagator.propagators2D.fresnel_zoom_xy import FresnelZoomXY2D
 
 from orangecontrib.wofry.util.wofry_objects import WofryData
 from orangecontrib.wofry.widgets.gui.ow_wofry_widget import WofryWidget
